==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/GrupaUprawnienieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.Uprawnienie;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class GrupaUprawnienieKey extends GenericDPSObject {
    /**
     * GRUPA_UPRAWNIENIE.GRUPA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long grupaId;

    /**
     * GRUPA_UPRAWNIENIE.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Uprawnienie nazwa;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_UPRAWNIENIE.GRUPA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getGrupaId() {
        return grupaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:40
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_UPRAWNIENIE.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Uprawnienie getNazwa() {
        return nazwa;
    }

    /**
     * GRUPA_UPRAWNIENIE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(Uprawnienie nazwa) {
        this.nazwa = nazwa;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaUprawnienieKey other = (GrupaUprawnienieKey) that;
        return (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", grupaId=").append(grupaId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/GrupaUprawnienieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.Uprawnienie;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class GrupaUprawnienieKey extends GenericDPSObject {
    /**
     * GRUPA_UPRAWNIENIE.GRUPA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long grupaId;

    /**
     * GRUPA_UPRAWNIENIE.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Uprawnienie nazwa;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return GRUPA_UPRAWNIENIE.GRUPA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getGrupaId() {
        return grupaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:44
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * GRUPA_UPRAWNIENIE.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return GRUPA_UPRAWNIENIE.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Uprawnienie getNazwa() {
        return nazwa;
    }

    /**
     * GRUPA_UPRAWNIENIE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(Uprawnienie nazwa) {
        this.nazwa = nazwa;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        GrupaUprawnienieKey other = (GrupaUprawnienieKey) that;
        return (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", grupaId=").append(grupaId);
        sb.append(", nazwa=").append(nazwa);
        sb.append("]");
        return sb.toString();
    }
}
